@@ -1,14 +1,14 @@
-### dyn.scale.R  (2006-04-25)
+### dyn.scale.R  (2008-11-14)
 ###
 ###    Dynamical Scale, Moments, and Weights
 ###
-### Copyright 2005-06 Rainer Opgen-Rhein and Korbinian Strimmer
+### Copyright 2005-2008 Rainer Opgen-Rhein and Korbinian Strimmer
 ###
 ###
 ###
 ### This file is part of the `GeneTS' library for R and related languages.
 ### It is made available under the terms of the GNU General Public
-### License, version 2, or at your option, any later version,
+### License, version 3, or at your option, any later version,
 ### incorporated herein by reference.
 ### 
 ### This program is distributed in the hope that it will be
@@ -26,37 +26,37 @@
 
 
 # mean and variance of longitudinal data matrix
-dyn.moments <- function(x)
+dyn.moments = function(x)
 {
-  w <- dyn.weights(x)
+  w = dyn.weights(x)
   
   return( wt.moments(x, w) )
 }
 
 # scale longitudinal data matrix
-dyn.scale <- function(x, center=TRUE, scale=TRUE, scale.by=c("sd", "mean"))
+dyn.scale = function(x, center=TRUE, scale=TRUE)
 {
-  w <- fda.weights(x)
-  x <- wt.scale(x, w, center, scale, scale.by)
+  w = dyn.weights(x)
+  x = wt.scale(x, w, center, scale)
 
   return( x )
 }
 
 # compute weights from 
-dyn.weights <- function(x)
+dyn.weights = function(x)
 {
   if ( is.longitudinal(x) )
   {
-    tvec <- get.time.repeats(x)$time
-    rvec <- get.time.repeats(x)$repeats
+    tvec = get.time.repeats(x)$time
+    rvec = get.time.repeats(x)$repeats
         
-    tw <- time2weights(tvec)
-    w <- rep(tw, rvec) / rep(rvec, rvec)
+    tw = time2weights(tvec)
+    w = rep(tw, rvec) / rep(rvec, rvec)
   }
   else if (is.matrix(x))
   {
-    n <- dim(x)[1]
-    w <- rep(1/n, n)
+    n = dim(x)[1]
+    w = rep(1/n, n)
   }
   else
   {
@@ -78,15 +78,15 @@ dyn.weights <- function(x)
 # example: for 6 equidistant points the weights
 #          are  c(0.1, 0.2, 0.2, 0.2, 0.2, 0.1) 
 
-time2weights <- function(t)
+time2weights = function(t)
 {
   # number of time points
-  u <- length(t) 
+  u = length(t) 
 
   if (u == 1) return(1)
 
-  dt <- diff(t)
-  w <- (c(0, dt) + c(dt, 0))/(2*sum(dt))
+  dt = diff(t)
+  w = (c(0, dt) + c(dt, 0))/(2*sum(dt))
 
   return(w)
 }
